@@ -1,3 +1,5 @@
+from typing import List
+
 from .typer import Typer
 
 
@@ -19,6 +21,9 @@ class NoopTyper(Typer):
     def insert_from_clipboard(self, active_window: str) -> None:
         raise NoTyperFoundException()
 
+    def type_numerical(self, codepoints: List[int], active_window: str) -> None:
+        raise NoTyperFoundException()
+
 
 class NoTyperFoundException(Exception):
     def __str__(self) -> str:
