@@ -1,4 +1,5 @@
 from subprocess import run
+from typing import List
 
 from ..abstractionhelper import is_installed, is_wayland
 from .typer import Typer
@@ -21,3 +22,8 @@ class WTypeTyper(Typer):
 
     def insert_from_clipboard(self, active_window: str) -> None:
         run(["wtype", "-M", "shift", "-P", "Insert", "-p", "Insert", "-m", "shift"])
+
+    def type_numerical(self, codepoints: List[int], active_window: str) -> None:
+        codepoint_list = " ".join([f"U{codepoint:x}" for codepoint in codepoints])
+
+        run(["wtype", "-M", "ctrl", "-M", "shift", codepoint_list, "-m", "ctrl", "-m", "shift"])
